@@ -231,7 +231,7 @@ class YOLO():
 
         return self.feature_extractor
 
-    def compile(self, optimizer="adam", lr=1e-4):
+    def compile(self, optimizer="adam", lr=1e-4, loss_scaling=False):
         """Defines the optimization part of the learning algorithm to our
         learning model.
 
@@ -241,9 +241,26 @@ class YOLO():
             lr_disc (Float, optional): Learning rate discriminator.
                 Defaults to 1e4.
         """
-        # TODO: more optimizer
-        if optimizer == "adam":
+        if optimizer == "adadelta":
+            self.optimizer = tf.keras.optimizers.Adadelta(lr)
+        elif optimizer == "adagrad":
+            self.optimizer = tf.keras.optimizers.Adagrad(lr)
+        elif optimizer == "adam":
             self.optimizer = tf.keras.optimizers.Adam(lr)
+        elif optimizer == "adamax":
+            self.optimizer = tf.keras.optimizers.Adamax(lr)
+        elif optimizer == "ftrl":
+            self.optimizer = tf.keras.optimizers.Ftrl(lr)
+        elif optimizer == "nadam":
+            self.optimizer = tf.keras.optimizers.Nadam(lr)
+        elif optimizer == "rmsprop":
+            self.optimizer = tf.keras.optimizers.RMSprop(lr)
+        elif optimizer == "sgd":
+            self.optimizer = tf.keras.optimizers.SGD(lr)
+
+        if loss_scaling:
+            self.optimizer = tf.keras.mixed_precision.LossScaleOptimizer(
+                self.optimizer)
 
         if self.checkpoint is None:
             self.checkpoint = tf.train.Checkpoint(optimizer=self.optimizer,
